@@ -16,12 +16,12 @@
 
 from typing import List
 
-from flwr_experimental.baseline.common import (
+from flwr_experimental.baseline.config import (
     configure_client_instances,
     sample_delay_factors,
 )
 from flwr_experimental.baseline.setting import Baseline, ClientSetting, ServerSetting
-from flwr_experimental.ops.cluster import Instance
+from flwr_experimental.ops.instance import Instance
 
 ROUNDS = 20
 MIN_NUM_CLIENTS = 80
@@ -53,7 +53,10 @@ def get_instance_name(
 
 
 def configure_uniform_clients(
-    iid_fraction: float, instance_names: List[str], num_clients: int, dry_run: bool,
+    iid_fraction: float,
+    instance_names: List[str],
+    num_clients: int,
+    dry_run: bool,
 ) -> List[ClientSetting]:
     """Configure `num_clients`, all using the same delay factor."""
     clients = []
